@@ -332,7 +332,7 @@ cdebconf_newt_handler_detect_keyboard(struct frontend *obj, struct question *q)
     char *result, *filename;
     int res;
 
-    filename = q_get_choices(q);
+    filename = q_get_choices(obj, q);
 	if (!filename || !*filename)
 		return DC_NOTOK;
     res = detect_keys(obj, &newt_dkf, filename, &result);
